<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	version="2.0"><!-- com.blogspot.hoekstra_christian.tools.manageOpatch -->
	<xsl:output method="html" encoding="UTF-8" indent="yes" />
	<xsl:template match="/">
		<xsl:variable name="ORACLE_HOME_LOC" select="PRD_LIST/@ORACLE_HOME_LOC" />
		<html>
			<head>
				<style>
					table {counter-reset: rowNumber -1;} table tr
					{counter-increment: rowNumber;} table tr td:first-child::before {
					content: counter(rowNumber); min-width: 1em; margin-right: 0.5em;}
					body, div, table, caption {font: Normal 12px Verdana, Tahoma,
					Helvetica, Sans-Serif;} td {vertical-align: text-top;} table
					{border-collapse: collapse;} caption { font-weight: bold;
					text-align: left} th {background-color: #f2f2f2; color: black;}
					table, th, td {border: 1px solid #ddd;} th, td {text-align: left;
					padding: 5px;} tr:hover{background-color:#f5f5f5} p.title
					{font-size: 14px; font-weight: bold; color: #000080;} td.width
					{max-width: 600px}</style>
			</head>
			<body>
				<h1>
					<xsl:text>Opatch Inventory Report</xsl:text>
				</h1>
				<p class="title">
					<xsl:text>Generated on </xsl:text>
					<xsl:value-of select="PRD_LIST/@GENERATED_ON" />
					<br />
					<xsl:text>Report run on </xsl:text>
					<xsl:value-of select="PRD_LIST/@HOST_NAME" />
					<br />
					<xsl:text>Report run against  </xsl:text>
					<xsl:value-of select="$ORACLE_HOME_LOC" />
					<br />
					<xsl:text>OS name: </xsl:text>
					<xsl:value-of select="PRD_LIST/@OS_NAME" />
					<br />
					<xsl:text>OS arch: </xsl:text>
					<xsl:value-of select="PRD_LIST/@OS_ARCH" />
					<br />
				</p>
				<table border="1">
					<caption>Opatch Installed Products</caption>
					<tr>
						<th />
						<th>Product Name</th>
						<th>Description</th>
						<th>Version</th>
						<th>Install Date</th>
					</tr>
					<xsl:for-each select="PRD_LIST/TL_LIST/COMP"><!--<xsl:for-each select="PRD_LIST/COMP_LIST/COMP"> -->
						<tr>
							<td />
							<td>
								<xsl:value-of select="EXT_NAME" />
							</td>
							<td>
								<xsl:value-of select="DESC" />
							</td>
							<td>
								<xsl:value-of select="@VER" />
							</td>
							<td>
								<xsl:value-of select="@INSTALL_TIME" />
							</td>
						</tr>
					</xsl:for-each>
				</table>
				<br />
				<table border="1">
					<caption>Installed Components</caption>
					<tr>
						<th />
						<th>Component Name</th>
						<th>Description</th>
						<th>Version</th>
					</tr>
					<xsl:for-each select="PRD_LIST/COMP_LIST/COMP">
						<tr>
							<td />
							<td>
								<xsl:value-of select="EXT_NAME" />
							</td>
							<td>
								<xsl:value-of select="DESC" />
							</td>
							<td>
								<xsl:value-of select="@VER" />
							</td>
						</tr>
					</xsl:for-each>
				</table>
				<br />
				<table border="1">
					<caption>Installed Patches</caption>
					<tr>
						<th />
						<th>Patch ID</th>
						<th>Release Date</th>
						<th>Install Date</th>
						<th>Components Effected</th>
						<th>Bugs Fixed</th>
					</tr>
					<xsl:for-each select="PRD_LIST/ONEOFF_LIST/ONEOFF">
						<xsl:variable name="REF_ID" select="@REF_ID" />
						<xsl:variable name="INV_LOC"
							select="concat('file:///', $ORACLE_HOME_LOC, '/inventory/oneoffs/', $REF_ID, '/etc/config/inventory.xml')" />
						<tr>
							<td />
							<td>
								<xsl:value-of select="$REF_ID" />
							</td>
							<td>
								<xsl:for-each
									select="document($INV_LOC)/oneoff_inventory/date_of_patch">
									<xsl:value-of select="concat(@year, '.', @month, '.', @day)" />
								</xsl:for-each>
							</td>
							<td>
								<xsl:value-of select="@INSTALL_TIME" />
							</td>
							<td>
								<xsl:for-each
									select="document($INV_LOC)/oneoff_inventory/required_components/component">
									<xsl:choose>
										<xsl:when test="@internal_name != ''">
											<xsl:value-of select="concat('- ', @internal_name)" />
											<br />
										</xsl:when>
										<xsl:otherwise>
											<xsl:text>n/a</xsl:text>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:for-each>
							</td>
							<td class="width">
								<xsl:for-each
									select="document($INV_LOC)/oneoff_inventory/base_bugs/bug">
									<xsl:value-of select="concat('- ',@description)" />
									<br />
								</xsl:for-each>
							</td>
						</tr>
					</xsl:for-each>
				</table>
				<br />
				<a href="http://christian-hoekstra.blogspot.com" target="_blank">christian-hoekstra.blogspot.com</a>
			</body>
		</html>
	</xsl:template>
</xsl:stylesheet>